==> qtjambi-xml-debuginfo-macos-6.6.2.jar: sources/QtJambiXml/QDomNotation_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtXml/qdom.h>
#include <QtCore/QVariant>
#include <QtCore/qtextstream.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QDomNotation(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDomNotation")
    QDomNotation *_ptr = reinterpret_cast<QDomNotation *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QDomNotation()
void __qt_construct_QDomNotation(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDomNotation()")
    Q_UNUSED(__java_arguments)
    QDomNotation *__qt_this = new(__qtjambi_ptr) QDomNotation();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QDomNotation::QDomNotation()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomNotation_initialize_1native__Lio_qt_xml_QDomNotation_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomNotation::QDomNotation()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomNotation, sizeof(QDomNotation), typeid(QDomNotation), false, &deleter_QDomNotation, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QDomNotation(QDomNotation)
void __qt_construct_QDomNotation_cref_QDomNotation(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDomNotation(QDomNotation)")
    jobject x0 = __java_arguments[0].l;
    const QDomNotation& __qt_x0 = qtjambi_cast<const QDomNotation& >(__jni_env, x0);
    QDomNotation *__qt_this = new(__qtjambi_ptr) QDomNotation(__qt_x0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QDomNotation::QDomNotation(QDomNotation)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomNotation_initialize_1native__Lio_qt_xml_QDomNotation_2Lio_qt_xml_QDomNotation_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject x0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomNotation::QDomNotation(QDomNotation)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = x0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomNotation_cref_QDomNotation, sizeof(QDomNotation), typeid(QDomNotation), false, &deleter_QDomNotation, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QDomNotation
void __qt_destruct_QDomNotation(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDomNotation")
    reinterpret_cast<QDomNotation*>(ptr)->~QDomNotation();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDomNotation::operator=(QDomNotation)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomNotation_assign_1native_1cref_1QDomNotation__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDomNotation *__qt_this = QtJambiAPI::objectFromNativeId<QDomNotation>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomNotation::operator=(QDomNotation)", __qt_this)
        const QDomNotation& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QDomNotation>(arg__1);
        (*__qt_this) = __qt_arg__1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDomNotation::publicId()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomNotation_publicId_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QDomNotation *__qt_this = QtJambiAPI::objectFromNativeId<QDomNotation>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomNotation::publicId()const", __qt_this)
        QString __qt_return_value = __qt_this->publicId();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDomNotation::systemId()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomNotation_systemId_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QDomNotation *__qt_this = QtJambiAPI::objectFromNativeId<QDomNotation>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomNotation::systemId()const", __qt_this)
        QString __qt_return_value = __qt_this->systemId();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomNotation_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QDomNotation *__qt_this = QtJambiAPI::objectFromNativeId<QDomNotation>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QDomNotation(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QDomNotation>("QDomNotation", "io/qt/xml/QDomNotation");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QDomNotation, {
        ConstructorInfo(&__qt_construct_QDomNotation, nullptr)
       ,ConstructorInfo(&__qt_construct_QDomNotation_cref_QDomNotation, "Lio/qt/xml/QDomNotation;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDomNotation);
    registerMetaType<QDomNotation>("QDomNotation");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-xml-debuginfo-macos-6.7.1.jar: sources/QtJambiXml/QDomNotation_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtXml/qdom.h>
#include <QtCore/QVariant>
#include <QtCore/qtextstream.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QDomNotation(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDomNotation")
    QDomNotation *_ptr = reinterpret_cast<QDomNotation *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QDomNotation()
void __qt_construct_QDomNotation(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDomNotation()")
    Q_UNUSED(__java_arguments)
    QDomNotation *__qt_this = new(__qtjambi_ptr) QDomNotation();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QDomNotation::QDomNotation()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomNotation_initialize_1native__Lio_qt_xml_QDomNotation_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomNotation::QDomNotation()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomNotation, sizeof(QDomNotation), typeid(QDomNotation), 0, false, &deleter_QDomNotation, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QDomNotation(QDomNotation)
void __qt_construct_QDomNotation_cref_QDomNotation(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDomNotation(QDomNotation)")
    jobject x0 = __java_arguments[0].l;
    const QDomNotation& __qt_x0 = qtjambi_cast<const QDomNotation&>(__jni_env, x0);
    QDomNotation *__qt_this = new(__qtjambi_ptr) QDomNotation(__qt_x0);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QDomNotation::QDomNotation(QDomNotation)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomNotation_initialize_1native__Lio_qt_xml_QDomNotation_2Lio_qt_xml_QDomNotation_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject x0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomNotation::QDomNotation(QDomNotation)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = x0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomNotation_cref_QDomNotation, sizeof(QDomNotation), typeid(QDomNotation), 0, false, &deleter_QDomNotation, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QDomNotation
void __qt_destruct_QDomNotation(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDomNotation")
    reinterpret_cast<QDomNotation*>(ptr)->~QDomNotation();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDomNotation::operator=(QDomNotation)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomNotation_assign_1native_1cref_1QDomNotation__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDomNotation *__qt_this = QtJambiAPI::objectFromNativeId<QDomNotation>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomNotation::operator=(QDomNotation)", __this_nativeId)
        const QDomNotation& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QDomNotation>(arg__1);
        (*__qt_this) = __qt_arg__1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDomNotation::publicId()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomNotation_publicId_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QDomNotation *__qt_this = QtJambiAPI::objectFromNativeId<QDomNotation>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomNotation::publicId()const", __this_nativeId)
        QString __qt_return_value = __qt_this->publicId();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDomNotation::systemId()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomNotation_systemId_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QDomNotation *__qt_this = QtJambiAPI::objectFromNativeId<QDomNotation>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomNotation::systemId()const", __this_nativeId)
        QString __qt_return_value = __qt_this->systemId();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomNotation_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QDomNotation *__qt_this = QtJambiAPI::objectFromNativeId<QDomNotation>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QDomNotation(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QDomNotation>("QDomNotation", "io/qt/xml/QDomNotation");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QDomNotation, {
        ConstructorInfo(&__qt_construct_QDomNotation, nullptr)
       ,ConstructorInfo(&__qt_construct_QDomNotation_cref_QDomNotation, "Lio/qt/xml/QDomNotation;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDomNotation);
    registerMetaType<QDomNotation>("QDomNotation");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
